==> ondir-0.1.3.tar.gz: ondir-0.1.3/src/Crash.h <==
#ifndef CRASH_MODULE_CRASH
#define CRASH_MODULE_CRASH

#include <cstdlib>
#include <unistd.h>
#include <sys/time.h>
#include <cstring>
#include <fstream>
#include <string>
#include <stdexcept>
#include <strstream>
#include <vector>

//<module name=fileSize include='fstream' description='Return the size of a file, in bytes'>
inline unsigned long fileSize(string const &filename) {
ifstream in(filename.c_str());

	in.seekg(ios::end);
	return in.tellg();
}
//</module>

//<module name=loadFile include='fstream' description='Load a file into a string'>
inline string loadFile(string const &filename) {
ifstream in(filename.c_str());
string out;

	getline(in, out,  '\0');
	return out;
}
//</module>

//<module name=saveString include='fstream' description='Save a string into a file'>
inline void saveString(string const &filename, string const &string) {
ofstream out(filename.c_str());

	out.write(string.c_str(), string.size());
}
//</module>

//<module name=touching description='Box/point intersection testing functions.'>
inline bool touching(float x, float y, float ox, float oy, float ow, float oh) {
	return x >= ox && y >= oy && x < ox + ow && y < oy + oh;
}

inline bool touching(float x, float y, float z,
	float ox, float oy, float oz,
	float ow, float oh, float od) {
	return x >= ox && y >= oy && z >= oz && x < ox + ow && y < oy + oh && z
		< oz + od;
}
//</module>

//<module name=drand description='Double random number in the range 1 >= x >= 0'>
double drand();
void sdrand(unsigned seed);
//</module>

//<module name=sleep description='Sleep for a floating point number of seconds'>
void sleep(double seconds);
//</module>

//<module name=time description='Number of seconds since 1970 as a double'>
double time();
//</module>

//<module name=getcwd description='Get current working directory'>
string getcwd();
//</module>

//<module name=CRC description='Return the CRC of a string'>
unsigned long crc(char const *buf, int len = -1);
//</module>

#endif

==> ondir-0.1.5.tar.gz: ondir-0.1.5/src/Crash.h <==
#ifndef CRASH_MODULE_CRASH
#define CRASH_MODULE_CRASH

#include <cstdlib>
#include <unistd.h>
#include <sys/time.h>
#include <cstring>
#include <fstream>
#include <string>
#include <vector>

//<module name=fileSize include='fstream' description='Return the size of a file, in bytes'>
inline unsigned long fileSize(string const &filename) {
ifstream in(filename.c_str());

	in.seekg(ios::end);
	return in.tellg();
}
//</module>

//<module name=loadFile include='fstream' description='Load a file into a string'>
inline string loadFile(string const &filename) {
ifstream in(filename.c_str());
string out;

	getline(in, out,  '\0');
	return out;
}
//</module>

//<module name=saveString include='fstream' description='Save a string into a file'>
inline void saveString(string const &filename, string const &string) {
ofstream out(filename.c_str());

	out.write(string.c_str(), string.size());
}
//</module>

//<module name=touching description='Box/point intersection testing functions.'>
inline bool touching(float x, float y, float ox, float oy, float ow, float oh) {
	return x >= ox && y >= oy && x < ox + ow && y < oy + oh;
}

inline bool touching(float x, float y, float z,
	float ox, float oy, float oz,
	float ow, float oh, float od) {
	return x >= ox && y >= oy && z >= oz && x < ox + ow && y < oy + oh && z
		< oz + od;
}
//</module>

//<module name=drand description='Double random number in the range 1 >= x >= 0'>
//double drand();
//void sdrand(unsigned seed);
//</module>

//<module name=sleep description='Sleep for a floating point number of seconds'>
void sleep(double seconds);
//</module>

//<module name=time description='Number of seconds since 1970 as a double'>
double time();
//</module>

//<module name=getcwd description='Get current working directory'>
string getcwd();
//</module>

//<module name=CRC description='Return the CRC of a string'>
unsigned long crc(char const *buf, int len = -1);
//</module>

#endif
